@@ -21,24 +21,24 @@ class ImpliesTestCase(unittest.TestCase):
         node = mg.findNode('mod')
         self.assertIsInstance(node, modulegraph.SourceModule)
 
-        node = mg.findNode('syslog')
+        node = mg.findNode('sqlite3')
         self.assertEqual(node, None)
 
         # Now check that adding an implied dependency actually adds
         # 'syslog' to the graph:
         mg = modulegraph.ModuleGraph(path=[root]+sys.path, implies={
-            'mod': ['syslog']})
+            'mod': ['sqlite3']})
         self.assertEqual(node, None)
         mg.run_script(os.path.join(root, 'script.py'))
         node = mg.findNode('mod')
         self.assertIsInstance(node, modulegraph.SourceModule)
 
-        node = mg.findNode('syslog')
-        self.assertIsInstance(node, modulegraph.Extension)
+        node = mg.findNode('sqlite3')
+        self.assertIsInstance(node, modulegraph.Package)
 
         # Check that the edges are correct:
-        self.assertTrue(mg.findNode('mod') in mg.get_edges(node)[1])
-        self.assertTrue(node in mg.get_edges(mg.findNode('mod'))[0])
+        self.assertIn(mg.findNode('mod'), mg.get_edges(node)[1])
+        self.assertIn(node, mg.get_edges(mg.findNode('mod'))[0])
 
     def testPackagedImplies(self):
         root = os.path.join(
@@ -51,27 +51,27 @@ class ImpliesTestCase(unittest.TestCase):
         node = mg.findNode('mod')
         self.assertIsInstance(node, modulegraph.SourceModule)
 
-        node = mg.findNode('syslog')
+        node = mg.findNode('sqlite3')
         self.assertEqual(node, None)
 
 
         # Now check that adding an implied dependency actually adds
         # 'syslog' to the graph:
         mg = modulegraph.ModuleGraph(path=[root]+sys.path, implies={
-            'pkg.relative': ['syslog']})
-        node = mg.findNode('syslog')
+            'pkg.relative': ['sqlite3']})
+        node = mg.findNode('sqlite3')
         self.assertEqual(node, None)
 
         mg.run_script(os.path.join(root, 'script.py'))
         node = mg.findNode('pkg.relative')
         self.assertIsInstance(node, modulegraph.SourceModule)
 
-        node = mg.findNode('syslog')
-        self.assertIsInstance(node, modulegraph.Extension)
+        node = mg.findNode('sqlite3')
+        self.assertIsInstance(node, modulegraph.Package)
 
         # Check that the edges are correct:
-        self.assertTrue(mg.findNode('pkg.relative') in mg.get_edges(node)[1])
-        self.assertTrue(node in mg.get_edges(mg.findNode('pkg.relative'))[0])
+        self.assertIn(mg.findNode('pkg.relative'), mg.get_edges(node)[1])
+        self.assertIn(node, mg.get_edges(mg.findNode('pkg.relative'))[0])
 
 
 if __name__ == '__main__':
