@@ -1,6 +1,9 @@
 import unittest
 from modulegraph import modulegraph
-import pkg_resources
+try:
+    import importlib.metadata
+except ImportError:
+    import pkg_resources
 import os
 from modulegraph import _imp as imp
 import sys
@@ -97,6 +100,13 @@ class TestFunctions (unittest.TestCase):
         self.assertRaises(ValueError, modulegraph._eval_str_tuple, "('a', ('b\", 'c'))")
 
     def test_namespace_package_path(self):
+        try:
+            import importlib.metadata
+        except ImportError:
+            pass
+        else:
+            raise unittest.SkipTest("Using importlib.metadata")
+
         class DS (object):
             def __init__(self, path, namespace_packages=None):
                 self.location = path
@@ -425,6 +435,12 @@ class TestNode (unittest.TestCase):
         if '__dict__' in d:
             # New in Python 3.4
             del d['__dict__']
+        if '__firstlineno__' in d:
+            # New in Python 3.13
+            del d['__firstlineno__']
+        if '__static_attributes__' in d:
+            # New in Python 3.13
+            del d['__static_attributes__']
         self.assertEqual(d, {})
 
     def assertHasExactMethods(self, klass, *methods):
@@ -437,6 +453,12 @@ class TestNode (unittest.TestCase):
         if '__dict__' in d:
             # New in Python 3.4
             del d['__dict__']
+        if '__firstlineno__' in d:
+            # New in Python 3.13
+            del d['__firstlineno__']
+        if '__static_attributes__' in d:
+            # New in Python 3.13
+            del d['__static_attributes__']
 
         for nm in methods:
             self.assertTrue(nm in d, "%s doesn't have attribute %r"%(klass, nm))
@@ -1040,7 +1062,7 @@ class TestModuleGraph (unittest.TestCase):
         graph.import_hook('unittest')
         # Don't use "distutils.command.build" here, causes problems on
         # Travis.
-        graph.import_hook('lib2to3.fixes.fix_apply')
+        #graph.import_hook('lib2to3.fixes.fix_apply')
 
         fp = StringIO()
         list(graph.itergraphreport())
