@@ -8,7 +8,7 @@ class TestVersions (unittest.TestCase):
         fn = os.path.join(
             os.path.dirname(os.path.dirname(os.path.abspath(__file__))),
             'setup.cfg')
-        with open(fn, 'rU') as fp:
+        with open(fn, 'r') as fp:
             for ln in fp:
                 if ln.startswith('version'):
                     version = ln.split('=')[-1].strip()
